rnalysis.feature\_name\_to\_wbgene.GeneNameTranslator
=====================================================

.. currentmodule:: rnalysis.feature_name_to_wbgene

.. autoclass:: GeneNameTranslator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
    :toctree:
   
      ~GeneNameTranslator.__init__
      ~GeneNameTranslator.generate_target_dict
      ~GeneNameTranslator.import_target
      ~GeneNameTranslator.read_reference
      ~GeneNameTranslator.rewrite_target
      ~GeneNameTranslator.run
   
   

   
   
